# Schematische Darstellung eines infinitesimal kleinen Raumwinkelelementes
# von Dorian Weber

reset
set encoding iso_8859_1
set terminal postscript eps enhanced color 24
set output "../P79_solidAngle.eps"

# Transformation in Polarkoordinaten erweist sich als sinnvoll
polarTrafoX(phi, theta) = sin(phi) * cos(theta)
polarTrafoY(phi, theta) = sin(phi) * sin(theta)
polarTrafoZ(phi, theta) = cos(phi)

# ############################################################### setup

# wir bentigen mehrere Lufe
set multiplot

# Standardeinstellungen vornehmen
set parametric
set xrange [-1.3:1.3]
set yrange [-1.3:1.3]
set zrange [-1.3:1.3]

set view 68, 115, 2.0
set origin 0, -0.05
set noxtics
set noytics
set noztics

set nokey
set border 0
set xyplane at 0
set size ratio 1.0

# Stildefinitionen

# Kugellinien
set style line 1 lt 1 lc rgb "grey30"

# Kugellinien fr phi = konstant
set style line 2 lt -1 lw 2 lc rgb "medium-blue"

# Kugellinien fr theta = konstant
set style line 3 lt -1 lw 2 lc rgb "red"

# innere Koordinatenachsen
set style arrow 1 nohead lt 2 lc rgb "dark-blue"

# Pfeile zum Raumwinkelelement
set style arrow 2 nohead lt 1 lw 2 lc rgb "dark-violet"

# Fensterrahmen
set style line 4 lt -1 lw 2 lc rgb "dark-violet"
set style arrow 3 nohead ls 4

# welches Element im Raster soll das Fenster sein
phi   = 9 * pi/20
#       ^- Zeile
theta = 4 * pi/10
#       ^- Spalte

# Berechnung der Fensterkoordinaten
wx_1 = polarTrafoX(phi, theta);             wy_1 = polarTrafoY(phi, theta);             wz_1 = polarTrafoZ(phi, theta)
wx_2 = polarTrafoX(phi-pi/20, theta);       wy_2 = polarTrafoY(phi-pi/20, theta);       wz_2 = polarTrafoZ(phi-pi/20, theta)
wx_3 = polarTrafoX(phi-pi/20, theta-pi/10); wy_3 = polarTrafoY(phi-pi/20, theta-pi/10); wz_3 = polarTrafoZ(phi-pi/20, theta-pi/10)
wx_4 = polarTrafoX(phi, theta-pi/10);       wy_4 = polarTrafoY(phi, theta-pi/10);       wz_4 = polarTrafoZ(phi, theta-pi/10)

# ############################################################### pass 1 - innere Komponenten

# als erstes werden die Linien zum Fenster geplottet
set arrow from 0,0,0 to wx_1, wy_1, wz_1 as 2
set arrow from 0,0,0 to wx_2, wy_2, wz_2 as 2
set arrow from 0,0,0 to wx_3, wy_3, wz_3 as 2
set arrow from 0,0,0 to wx_4, wy_4, wz_4 as 2

# davor sollte aber noch das innere Koordinatenkreuz liegen
set arrow from -1,0,0 to 1,0,0 as 1
set arrow from 0,-1,0 to 0,1,0 as 1
set arrow from 0,0,-1 to 0,0,1 as 1

# Funktion interessiert uns grad nicht
set isosamples 2
splot 0, 0, 0

# ############################################################### pass 2 - Kugel

# setup fr den nchsten render-pass
set isosamples 21

set urange [0:pi]
set vrange [0:2*pi]

set hidden3d

# inneres Koordinatenkreuz wird wegen hidden3d durch die Kugel verdeckt
# dadurch wird unser gestricheltes Kreuz nicht bermalt
set xzeroaxis lt -1
set yzeroaxis lt -1
set zzeroaxis lt -1

unset arrow

# plot der Kugel
splot polarTrafoX(u,v),\
      polarTrafoY(u,v),\
      polarTrafoZ(u,v) ls 1

# ############################################################### pass 3 - phi = konstant

unset xzeroaxis
unset yzeroaxis
unset zzeroaxis

set urange [phi-pi/20.0:phi]
set isosamples 2, 21

# mit diesem Hack wird sichergestellt, dass die inneren Linien nicht auftauchen (culling)
# das funktioniert, weil der Linienstil -2 nicht existiert
set hidden3d offset -1

# plot fr konstantes phi
splot polarTrafoX(u,v),\
      polarTrafoY(u,v),\
      polarTrafoZ(u,v) ls 2

# ############################################################### pass 4 - theta = konstant

set urange [0:pi-pi/20.0]
set vrange [theta-pi/10.0:theta]
set isosamples 20, 2

set hidden3d offset -1

# plot fr konstantes theta
splot polarTrafoX(u,v),\
      polarTrafoY(u,v),\
      polarTrafoZ(u,v) ls 3

# ############################################################### pass 5 - 3D Labels und Fenster

# erst die 3D Achsenlabels
set label "x_1" at 1.4,0,0 center
set label "x_2" at 0,1.4,0 center
set label "x_3" at 0,0,1.4 center

# dann das Fenster
set arrow from wx_1, wy_1, wz_1 to wx_2, wy_2, wz_2 as 3
set arrow from wx_2, wy_2, wz_2 to wx_3, wy_3, wz_3 as 3
set arrow from wx_3, wy_3, wz_3 to wx_4, wy_4, wz_4 as 3
set arrow from wx_4, wy_4, wz_4 to wx_1, wy_1, wz_1 as 3

# Funktion interessiert uns nicht
set isosamples 2,2
splot 0, 0, 0

# ############################################################### pass 6 - 2D Labels

unset label
unset arrow

# Postscript hacking fr griechische Buchstaben
set label "d{/Symbol W} = sin {/Symbol J} d{/Symbol J} d{/Symbol j}" at 1.8,1.4 right tc ls 4
set label "[{/Symbol J}, {/Symbol J} + d{/Symbol J}]"                at 1.8,1.2 right tc ls 2
set label "[{/Symbol j}, {/Symbol j} + d{/Symbol j}]"                at 1.8,1.0 right tc ls 3

# Funktion interessiert uns nicht
set samples 2
plot 0, 0
